package com.jiuqi.util.inifile;

import com.jiuqi.util.Stream;
import java.util.ArrayList;
import java.util.List;

/* loaded from: com_jiuqi_util_inifile.jar:com/jiuqi/util/inifile/Section.class */
public class Section {
    private String name;
    private List list = new ArrayList();
    private IniBuffer buffer;
    private boolean founded;

    public Section(String aName, IniBuffer aBuffer) {
        this.name = aName;
        this.buffer = aBuffer;
    }

    public String name() {
        return this.name;
    }

    public int count() {
        return this.list.size();
    }

    public Ident get(int index) {
        return (Ident) this.list.get(index);
    }

    public void readInfo() {
        clear();
        int l = this.buffer.readInfoInteger();
        for (int i = 0; i < l; i++) {
            Ident node = new Ident();
            node.name = this.buffer.readInfoString();
            node.type = this.buffer.readInfoByte();
            node.position = this.buffer.readInfoInteger();
            this.list.add(node);
            if (node.type == 7) {
                node.child = new BufferIni(this.buffer);
                node.child.readInfo();
            }
        }
    }

    public void writeInfo() {
        int l = count();
        this.buffer.writeInfoInteger(l);
        for (int i = 0; i < l; i++) {
            Ident node = get(i);
            this.buffer.writeInfoString(node.name);
            this.buffer.writeInfoByte(node.type);
            this.buffer.writeInfoInteger(node.position);
            if (node.child != null) {
                node.child.writeInfo();
            }
        }
    }

    public void clear() {
        this.list.clear();
    }

    public void deleteKey(int index) {
        this.list.remove(index);
    }

    public void deleteKey(String ident) {
        int i = find(ident);
        if (this.founded) {
            this.list.remove(i);
        }
    }

    public void writeNull(String ident) {
        deleteKey(ident);
    }

    public void writeBoolean(String ident, boolean value) {
        Ident node = findNodeCreate(ident);
        node.type = (byte) 1;
        node.child = null;
        node.position = this.buffer.writeBoolean(value);
    }

    public void writeDouble(String ident, double value) {
        Ident node = findNodeCreate(ident);
        node.type = (byte) 3;
        node.child = null;
        node.position = this.buffer.writeDouble(value);
    }

    public void writeDateTime(String ident, long value) {
        writeLong(ident, value);
    }

    public void writeInteger(String ident, int value) {
        Ident node = findNodeCreate(ident);
        node.type = (byte) 2;
        node.child = null;
        node.position = this.buffer.writeInteger(value);
    }

    public void writeLong(String ident, long value) {
        Ident node = findNodeCreate(ident);
        node.type = (byte) 4;
        node.child = null;
        node.position = this.buffer.writeLong(value);
    }

    public void writeString(String ident, String value) {
        if (value == null) {
            deleteKey(ident);
            return;
        }
        Ident node = findNodeCreate(ident);
        node.type = (byte) 5;
        node.child = null;
        node.position = this.buffer.writeString(value);
    }

    public void writeStream(String ident, Stream stream) {
        try {
            Ident node = findNodeCreate(ident);
            node.type = (byte) 6;
            node.child = null;
            int l = (int) (stream.getSize() - stream.getPosition());
            node.position = this.buffer.writeInteger(l);
            this.buffer.writeStream(stream, l);
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    public BufferIni writeIni(String ident) {
        Ident node = findNodeCreate(ident);
        node.type = (byte) 7;
        if (node.child == null) {
            node.child = new BufferIni(this.buffer);
        }
        return node.child;
    }

    public int find(String ident) {
        this.founded = false;
        int l = 0;
        int h = this.list.size() - 1;
        while (l <= h) {
            int i = (l + h) / 2;
            int c = get(i).name.compareTo(ident);
            if (c < 0) {
                l = i + 1;
            } else {
                h = i - 1;
                if (c == 0) {
                    this.founded = true;
                    l = i;
                }
            }
        }
        return l;
    }

    public Ident findNode(String ident) {
        int i = find(ident);
        if (this.founded) {
            return get(i);
        }
        return null;
    }

    public Ident findNodeCreate(String ident) {
        int i = find(ident);
        if (this.founded) {
            return get(i);
        }
        Ident ret = new Ident();
        ret.name = ident;
        this.list.add(i, ret);
        return ret;
    }

    public boolean isNull(String ident) {
        Ident node = findNode(ident);
        return node == null;
    }

    public BufferIni readIni(String ident) {
        int i = find(ident);
        if (this.founded) {
            return get(i).child;
        }
        return null;
    }

    public boolean readBoolean(String ident, boolean defValue) {
        Ident node = findNode(ident);
        if (node != null) {
            return this.buffer.readBoolean(node.position);
        }
        return defValue;
    }

    public double readDouble(String ident, double defValue) {
        Ident node = findNode(ident);
        if (node != null) {
            return this.buffer.readDouble(node.position);
        }
        return defValue;
    }

    public long readDateTime(String ident, long defValue) {
        return readLong(ident, defValue);
    }

    public int readInteger(String ident, int defValue) {
        Ident node = findNode(ident);
        if (node != null) {
            return this.buffer.readInteger(node.position);
        }
        return defValue;
    }

    public long readLong(String ident, long defValue) {
        Ident node = findNode(ident);
        if (node != null) {
            return this.buffer.readLong(node.position);
        }
        return defValue;
    }

    public String readString(String ident, String defValue) {
        Ident node = findNode(ident);
        if (node != null) {
            return this.buffer.readString(node.position);
        }
        return defValue;
    }

    public void readStream(String ident, Stream stream) {
        Ident node = findNode(ident);
        if (node != null) {
            try {
                int l = this.buffer.readInteger(node.position);
                this.buffer.readStream(stream, node.position + 4, l);
            } catch (Exception ex) {
                ex.printStackTrace();
            }
        }
    }
}
